
from django.shortcuts import get_object_or_404, render
from django.contrib.auth.views import redirect_to_login

from flatpages.models import FlatPage
from flatpages.settings import DEFAULT_TEMPLATE


def flatpage(request, url):

    if not url.startswith('/'):
        url = '/' + url

    obj = get_object_or_404(FlatPage, url=url)

    if obj.registration_required and not request.user.is_authenticated():
        return redirect_to_login(request.path)

    template_name = obj.template_name or DEFAULT_TEMPLATE

    return render(request, template_name, {'flatpage': obj})



# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-05 10:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='FlatPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(db_index=True, max_length=100, verbose_name='URL')),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('content', models.TextField(blank=True, verbose_name='Content')),
                ('template_name', models.CharField(blank=True, help_text="Example: 'flatpages/contact_page.html'. If this isn't provided, the system will use 'flatpages/default.html'.", max_length=70, verbose_name='Template name')),
                ('registration_required', models.BooleanField(default=False, help_text='If this is checked, only logged-in users will be able to view the page.', verbose_name='registration required')),
            ],
            options={
                'ordering': ['url'],
                'verbose_name': 'Flat page',
                'verbose_name_plural': 'Flat pages',
            },
        ),
    ]




from django.db import models
from django.utils.translation import ugettext_lazy as _


class FlatPage(models.Model):

    url = models.CharField(_('URL'), max_length=100, db_index=True)

    title = models.CharField(_('Title'), max_length=200)

    content = models.TextField(_('Content'), blank=True)

    template_name = models.CharField(
        _('Template name'), max_length=70, blank=True,
        help_text=_(
            "Example: 'flatpages/contact_page.html'. If this isn't provided, "
            "the system will use 'flatpages/default.html'."))

    registration_required = models.BooleanField(
        _('registration required'),
        help_text=_("If this is checked, only logged-in "
                    "users will be able to view the page."), default=False)

    class Meta:
        verbose_name = _('Flat page')
        verbose_name_plural = _('Flat pages')
        ordering = ['url']

    def __str__(self):
        return "%s -- %s" % (self.url, self.title)




from django.utils.module_loading import import_string

from flatpages.settings import FLATPAGE_EDITORS


def get_editor_widget(editor_name):

    if editor_name:
        try:
            return import_string(FLATPAGE_EDITORS[editor_name])
        except ImportError:
            raise Exception('Flatpage editor module is undefined')
        except KeyError:
            raise Exception('Unknown flatpage editor module')

    return None




from django import forms
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from flatpages.models import FlatPage


class FlatpageForm(forms.ModelForm):

    url = forms.RegexField(
        label=_("URL"), max_length=100, regex=r'^[-\w/\.~]+$',
        help_text=_("Example: '/about/contact/'. Make sure to have leading"
                    " and trailing slashes."),
        error_messages={
            "invalid": _("This value must contain only letters, numbers,"
                         " dots, underscores, dashes, slashes or tildes."),
        }
    )

    def clean_url(self):
        url = self.cleaned_data['url']

        if not url.startswith('/'):
            raise forms.ValidationError(
                _("URL is missing a leading slash."))

        if settings.APPEND_SLASH and not url.endswith('/'):
            raise forms.ValidationError(
                _("URL is missing a trailing slash."))

        return url

    class Meta:
        model = FlatPage
        fields = '__all__'




from importlib import import_module

from django.apps import apps
from django.db import models
from django.contrib import admin

from flatpages.forms import FlatpageForm
from flatpages.models import FlatPage
from flatpages.lib import get_editor_widget
from flatpages.settings import DEFAULT_EDITOR


def _get_flatpage_admin_base_class():

    if apps.is_installed('modeltranslation'):
        return import_module('modeltranslation.admin').TranslationAdmin

    return admin.ModelAdmin


class FlatPageAdmin(_get_flatpage_admin_base_class()):

    form = FlatpageForm

    list_display = ['url', 'title']

    list_filter = ['registration_required']

    search_fields = ['url', 'title']

    def __init__(self, *args, **kwargs):

        if DEFAULT_EDITOR:
            self.formfield_overrides = {
                models.TextField: {'widget': get_editor_widget(DEFAULT_EDITOR)}
            }

        super(FlatPageAdmin, self).__init__(*args, **kwargs)


admin.site.register(FlatPage, FlatPageAdmin)




EDITOR_CKEDITOR = 'CKEDITOR'
EDITOR_CKEDITOR_UPLOADER = 'CKEDITOR_UPLOADER'
EDITOR_MARTOR = 'MARTOR'

FLATPAGE_EDITORS = {
    EDITOR_CKEDITOR: 'ckeditor.widgets.CKEditorWidget',
    EDITOR_CKEDITOR_UPLOADER: (
        'ckeditor_uploader.widgets.CKEditorUploadingWidget'),
    EDITOR_MARTOR: 'martor.widgets.AdminMartorWidget'
}




from django.conf import settings

from flatpages.constants import FLATPAGE_EDITORS


DEFAULT_EDITOR = getattr(settings, 'FLATPAGE_DEFAULT_EDITOR', None)

EDITORS = getattr(settings, 'FLATPAGE_EDITORS', FLATPAGE_EDITORS)

DEFAULT_TEMPLATE = getattr(
    settings, 'FLATPAGE_DEFAULT_TEMPLATE', 'flatpages/default.html')




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class FlatPagesConfig(AppConfig):
    name = 'flatpages'
    verbose_name = _("Flat Pages")


default_app_config = 'flatpages.FlatPagesConfig'

__version__ = '3.6'
